==> unicore-uvos-server-1.5.1-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/server/idresolver/TLSResolver.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Aug 17, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.server.idresolver;

import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;

import javax.security.auth.x500.X500Principal;

import org.apache.log4j.Logger;

import eu.unicore.security.SecurityTokens;

import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.IdentityType;
import pl.edu.icm.unicore.uvos.api.exceptions.UVOSException;
import pl.edu.icm.unicore.uvos.engine.InternalAuthorization;
import pl.edu.icm.unicore.uvos.engine.SecurityContext;
import pl.edu.icm.unicore.uvos.idhelpers.X509IdentityHelper;

/**
 * Resolves TLS certificate as identity of X509CERT or DN type
 * @author K. Benedyczak
 */
public class TLSResolver extends AbstractResolver
{
	private static final Logger log = Logger.getLogger(TLSResolver.class);
	private boolean tlsDNFirst;
	
	public TLSResolver(boolean tlsDNFirst, InternalAuthorization voAuthz)
	{
		super(voAuthz);
		this.tlsDNFirst = tlsDNFirst;
	}
	
	public SecurityContext resolve(SecurityTokens input) 
		throws IdUnresolvedException, UVOSException
	{
		Identity id;
		if (tlsDNFirst)
			id = resolveDN(input);
		else
			id = resolveFullCert(input);
		if (id == null)
			return null;
		
		try
		{
			return authenticate(id, "TLS");
		} catch (IdUnresolvedException e)
		{
			if (tlsDNFirst)
				id = resolveFullCert(input);
			else
				id = resolveDN(input);
			return authenticate(id, "TLS");
		} 
	}
	
	private Identity resolveFullCert(SecurityTokens input)
	{
		X509Certificate cert = input.getEffectiveUserCertificate();
		if (cert == null)
			return null;
		try
		{
			return X509IdentityHelper.convertCert(cert);
		} catch (CertificateException e)
		{
			log.error("Error during creation of identity " +
					"from certificate", e);
			return null;
		}
	}
	
	private  Identity resolveDN(SecurityTokens input)
	{
		X500Principal subject = input.getEffectiveUserName();
		if (subject == null)
			return null;
		String id = subject.getName();
		Identity idRet = new Identity(IdentityType.DN, id, null);
		return idRet;
	}
}

==> unicore-uvos-server-1.6.0-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/server/idresolver/TLSResolver.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Aug 17, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.server.idresolver;

import java.io.IOException;
import java.security.cert.X509Certificate;

import javax.security.auth.x500.X500Principal;

import org.apache.log4j.Logger;

import eu.unicore.security.SecurityTokens;
import eu.unicore.util.Log;

import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.IdentityType;
import pl.edu.icm.unicore.uvos.api.exceptions.UVOSException;
import pl.edu.icm.unicore.uvos.engine.InternalAuthorization;
import pl.edu.icm.unicore.uvos.engine.SecurityContext;
import pl.edu.icm.unicore.uvos.idhelpers.X509IdentityHelper;
import pl.edu.icm.unicore.uvos.util.UVOSServerProperties;

/**
 * Resolves TLS certificate as identity of X509CERT or DN type
 * @author K. Benedyczak
 */
public class TLSResolver extends AbstractResolver
{
	private static final Logger log = Log.getLogger(UVOSServerProperties.LOG_PFX, TLSResolver.class);
	private boolean tlsDNFirst;
	
	public TLSResolver(boolean tlsDNFirst, InternalAuthorization voAuthz)
	{
		super(voAuthz);
		this.tlsDNFirst = tlsDNFirst;
	}
	
	public SecurityContext resolve(SecurityTokens input) 
		throws IdUnresolvedException, UVOSException
	{
		Identity id;
		if (tlsDNFirst)
			id = resolveDN(input);
		else
			id = resolveFullCert(input);
		if (id == null)
			return null;
		
		try
		{
			return authenticate(id, "TLS");
		} catch (IdUnresolvedException e)
		{
			if (tlsDNFirst)
				id = resolveFullCert(input);
			else
				id = resolveDN(input);
			return authenticate(id, "TLS");
		} 
	}
	
	private Identity resolveFullCert(SecurityTokens input)
	{
		X509Certificate cert = input.getEffectiveUserCertificate();
		if (cert == null)
			return null;
		try
		{
			return X509IdentityHelper.convertCert(cert);
		} catch (IOException e)
		{
			log.error("Error during creation of identity " +
					"from certificate", e);
			return null;
		}
	}
	
	private  Identity resolveDN(SecurityTokens input)
	{
		X500Principal subject = input.getEffectiveUserName();
		if (subject == null)
			return null;
		String id = subject.getName();
		Identity idRet = new Identity(IdentityType.DN, id, null);
		return idRet;
	}
}
